docs.rs failed to build dioxus-window-0.1.0-alpha.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
dioxus-window-0.0.0
Dioxus Window
Window utilities for Dioxus.
Features:
- Theme
- Window Size
Usage
Add dioxus-window to your Cargo.toml:
[]
= "0.1"
Dioxus Compatibility
This table represents the compatibility between this crate and Dioxus versions. The crate version supports a Dioxus version up until the next crate version in the table.
E.g. if crate version 0.1 supported Dioxus 0.6 and crate version 0.4 supported Dioxus 0.7, crate versions 0.1, 0.2, and 0.3 would support Dioxus 0.6.
| Crate Version | Dioxus Version |
|---|---|
| 0.1 | 0.6 |